# Genetic Opposite Color (geneticocolor)

Geneticocolor is a python package for color sets generation.

## Install
Using shell just write the following line:
```
$ pip install geneticocolor
```
## How to use
Once installed, you can import and use the library in any python file.
```
import geneticocolor.color_generator as generator
import matplotlib.pyplot as plt

colors = generator.generate(x, y, point_classes)
plt.scatter(x, y, colors)

```
## More about the implementantion
